<?php
/**
 * The header for our theme
 *
 * This is the template that displays all of the <head> section and everything up until <div id="content">
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package Elemento Business
 */
?>

<!DOCTYPE html>
<html <?php language_attributes(); ?>>
<head>

<meta http-equiv="Content-Type" content="<?php echo esc_attr(get_bloginfo('html_type')); ?>; charset=<?php echo esc_attr(get_bloginfo('charset')); ?>" />
<meta name="viewport" content="width=device-width, initial-scale=1.0, maximum-scale=1.2, user-scalable=yes" />

<?php wp_head(); ?>

</head>

<body <?php body_class(); ?>>

<?php
	if ( function_exists( 'wp_body_open' ) )
	{
		wp_body_open();
	}else{
		do_action('wp_body_open');
	}
?>
<?php if(get_theme_mod('elemento_business_preloader_hide','')){ ?>
	<div class="loader">
		<div class="preloader">
	    <div class="diamond">
	        <span></span>
	        <span></span>
	        <span></span>
	    </div>
		</div>
	</div>
<?php } ?>
<a class="skip-link screen-reader-text" href="#content"><?php esc_html_e( 'Skip to content', 'elemento-business' ); ?></a>

<div class="topheader py-2">
	<div class="container">
		<div class="row">
			<div class="col-lg-4 col-md-4 col-sm-4 align-self-center">
				<?php if ( get_theme_mod('elemento_business_header_timing') ) : ?>
					<p class="mb-0 text-center text-md-left"><i class="far fa-clock mr-2"></i><?php echo esc_html( get_theme_mod('elemento_business_header_timing' ) ); ?></p>
				<?php endif; ?>
			</div>
			<div class="col-lg-4 col-md-4 col-sm-4 text-md-right text-center align-self-center">
				<?php if ( get_theme_mod('elemento_business_header_phone_number') ) : ?>
					<span class="mr-4"><i class="fas fa-phone mr-2"></i><?php echo esc_html( get_theme_mod('elemento_business_header_phone_number' ) ); ?></span>
				<?php endif; ?>
				<?php if ( get_theme_mod('elemento_business_header_email') ) : ?>
					<span ><i class="fas fa-paper-plane mr-2"></i><?php echo esc_html( get_theme_mod('elemento_business_header_email' ) ); ?></span>
				<?php endif; ?>
			</div>
			<div class="col-lg-4 col-md-4 col-sm-4 align-self-center">
				<?php $elemento_business_settings = get_theme_mod( 'elemento_business_social_links_settings' ); ?>
				<div class="social-links text-center text-md-right">
					<?php if ( is_array($elemento_business_settings) || is_object($elemento_business_settings) ){ ?>
						<span><?php esc_html_e('Connect With Us -','elemento-business'); ?></span>
				    	<?php foreach( $elemento_business_settings as $elemento_business_setting ) { ?>
					        <a href="<?php echo esc_url( $elemento_business_setting['link_url'] ); ?>">
					            <i class="<?php echo esc_attr( $elemento_business_setting['link_text'] ); ?> mr-2"></i>
					        </a>
				    	<?php } ?>
					<?php } ?>
				</div>
			</div>
		</div>
	</div>
</div>

<header id="site-navigation" class="header text-center text-md-left py-2">
	<div class="container">
		<div class="row">
			<div class="col-lg-3 col-md-3 col-sm-4 align-self-center">
				<div class="logo">
		    		<div class="logo-image">
		    			<?php echo esc_url( the_custom_logo() ); ?>
			    	</div>
						<div class="logo-content">
				    	<?php
				    		if ( get_theme_mod('elemento_business_display_header_title', true) == true ) :
				      			echo '<a href="' . esc_url(home_url('/')) . '" title="' . esc_attr(get_bloginfo('name')) . '">';
				      			echo esc_attr(get_bloginfo('name'));
				      			echo '</a>';
			      		 	endif;
			      		 	if ( get_theme_mod('elemento_business_display_header_text', true) == true ) :
				      			echo '<span>'. esc_attr(get_bloginfo('description')) . '</span>';
				      		endif;
					    ?>
					</div>
				</div>
		   	</div>
			<div class="col-lg-6 col-md-6 col-sm-4 align-self-center">
				<?php if(has_nav_menu('main-menu')){ ?>
					<button class="menu-toggle my-3 py-2 px-3" aria-controls="top-menu" aria-expanded="false" type="button">
						<span aria-hidden="true"><?php esc_html_e( 'Menu', 'elemento-business' ); ?></span>
					</button>
					<nav id="main-menu" class="close-panal">
						<?php
							wp_nav_menu( array(
								'theme_location' => 'main-menu',
								'container' => 'false'
							));
						?>
						<button class="close-menu my-2 p-2" type="button">
							<span aria-hidden="true"><i class="fa fa-times"></i></span>
						</button>
					</nav>
				<?php }?>
			</div>
			<div class="col-lg-3 col-md-3 col-sm-4 align-self-center text-center text-md-right head-btn mb-2 mb-lg-0">
				<?php if ( get_theme_mod('elemento_business_consultant_btn_text') || get_theme_mod('elemento_business_consultant_btn_url') ) : ?>
					<a href="<?php echo esc_url( get_theme_mod('elemento_business_consultant_btn_url' ) ); ?>"><?php echo esc_html( get_theme_mod('elemento_business_consultant_btn_text' ) ); ?></a>
				<?php endif; ?>
			</div>
	   	</div>
	</div>
</header>
